package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysWorkConfig;

/**
 * 参数配置Service接口
 * 
 * @author qy
 * @date 2024-11-25
 */
public interface ISysWorkConfigService 
{
    /**
     * 查询参数配置
     * 
     * @param id 参数配置主键
     * @return 参数配置
     */
    public SysWorkConfig selectSysWorkConfigById(Long id);

    /**
     * 查询参数配置列表
     * 
     * @param sysWorkConfig 参数配置
     * @return 参数配置集合
     */
    public List<SysWorkConfig> selectSysWorkConfigList(SysWorkConfig sysWorkConfig);

    /**
     * 新增参数配置
     * 
     * @param sysWorkConfig 参数配置
     * @return 结果
     */
    public int insertSysWorkConfig(SysWorkConfig sysWorkConfig);

    /**
     * 修改参数配置
     * 
     * @param sysWorkConfig 参数配置
     * @return 结果
     */
    public int updateSysWorkConfig(SysWorkConfig sysWorkConfig);

    /**
     * 批量删除参数配置
     * 
     * @param ids 需要删除的参数配置主键集合
     * @return 结果
     */
    public int deleteSysWorkConfigByIds(Long[] ids);

    /**
     * 删除参数配置信息
     * 
     * @param id 参数配置主键
     * @return 结果
     */
    public int deleteSysWorkConfigById(Long id);
}
